@@ -4,7 +4,7 @@ import asyncio
 import weakref
 from functools import partial
 from random import randint
-from typing import List, Union, Tuple, Iterable
+from typing import List, Union, Tuple, Iterable, Set
 
 from aiokafka import AIOKafkaConsumer, ConsumerRebalanceListener, ConsumerRecord
 from humanize import naturalsize
@@ -82,7 +82,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
                 )/SECOND
             return values
 
-    _consumer: AIOKafkaConsumer
+    consumer: AIOKafkaConsumer
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -149,7 +149,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             await asyncio.wait(wait_for, timeout=1)
 
         try:
-            await self._consumer.stop()
+            await self.consumer.stop()
         except Exception as e:
             self.logger.exception(f"stopping kafka consumer failed {e.__class__.__name__}({e})")
         self.logger.debug("kafka consumer stopped")
@@ -196,18 +196,18 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
 
         try:
             # commit message
-            await self._consumer.commit({
+            await self.consumer.commit({
                 tp: offset + 1
             })
             return True
         except Exception as exc:
             self.logger.exception(f"commit failed {exc.__class__.__name__}({exc})")
             # seek to fetch same task again
-            self._consumer.seek(tp, offset)
+            self.consumer.seek(tp, offset)
             return False
         finally:
             # resume partition
-            self._consumer.resume(tp)
+            self.consumer.resume(tp)
             self.logger.debug(f"{tp} resumed")
 
     async def handle_partitions_revoke(self, revoked):
@@ -282,7 +282,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         """
         while not self.is_stopping:
 
-            msg: ConsumerRecord = await self._consumer.getone()
+            msg: ConsumerRecord = await self.consumer.getone()
 
             try:
                 # wait for getter not longer then half pool interval
@@ -291,13 +291,13 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
                 )
             except asyncio.TimeoutError:
                 # seek back to get same message again
-                self._consumer.seek(TopicPartition(topic=msg.topic, partition=msg.partition), msg.offset)
+                self.consumer.seek(TopicPartition(topic=msg.topic, partition=msg.partition), msg.offset)
                 continue
             else:
                 self._getters_queue.task_done()
                 if getter.cancelled():
                     # seek back to get same message again
-                    self._consumer.seek(TopicPartition(topic=msg.topic, partition=msg.partition), msg.offset)
+                    self.consumer.seek(TopicPartition(topic=msg.topic, partition=msg.partition), msg.offset)
                     continue
 
                 getter.set_result(msg)
@@ -308,7 +308,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             # pause the topic-partition to make sure that no more messages will be fetched
             # from this topic-partition
             tp = TopicPartition(topic=msg.topic, partition=msg.partition)
-            self._consumer.pause(tp)
+            self.consumer.pause(tp)
             self.logger.debug(f"{tp} paused")
 
     def _fetch_messages_done(self, fut):
@@ -328,7 +328,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             self._start_fetching()
 
     async def _start_consumer(self):
-        self._consumer = AIOKafkaConsumer(
+        self.consumer = AIOKafkaConsumer(
             client_id=get_node_id(),
             bootstrap_servers=self.settings.kafka_hosts,
             auto_offset_reset='earliest',
@@ -344,7 +344,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         )
         self.logger.debug("consumer created")
         try:
-            await self._consumer.start()
+            await self.consumer.start()
         except Exception as exc:
             self.logger.exception(f"unable to start Kafka consumer: {exc.__class__.__name__}({exc})", exc_info=True)
             raise
@@ -359,8 +359,8 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         :param queue_name:
         :return:
         """
-        topics = self._consumer.subscription() | set(queue_name)
-        self._consumer.subscribe(topics=list(topics), listener=RebalanceListener(self))
+        topics = self.consumer.subscription() | set(queue_name)
+        self.consumer.subscribe(topics=list(topics), listener=RebalanceListener(self))
 
     async def unsubscribe(self, queue_name: Iterable[str]):
         """
@@ -368,8 +368,55 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         :param queue_name:
         :return:
         """
-        topics = self._consumer.subscription() ^ set(queue_name)
-        self._consumer.subscribe(topics=list(topics), listener=RebalanceListener(self))
+        topics = self.consumer.subscription() ^ set(queue_name)
+        self.consumer.subscribe(topics=list(topics), listener=RebalanceListener(self))
 
     async def subscription(self) -> Iterable[str]:
-        return self._consumer.subscription()
+        return self.consumer.subscription()
+
+
+class AssignKafkaSubscriber(AsyncKafkaSubscriber):
+    """
+    An alternative Kafka subscriber which uses `assign` method instead of `subscribe`.
+    This subscribed may work with consumer group which enables offset commits or without it.
+
+    If no CG is given subscriber is seeking to the end of assigned topics just after assignment.
+    If CG is set, subscribed does not seek.
+
+    This subscriber assigns only to partition 0 so it works only with topics which have one
+    partition. If you'd like to work with multiple partitions overload subscribe/unsubscribe methods
+    accordingly and decide on which condition assign partition to subscriber instances
+    """
+
+    class Config(AsyncKafkaSubscriber.Config):
+        consumer_group: str = None
+        topics: Union[List[str], str] = []
+
+    async def subscribe(self, queue_name: Iterable[str]):
+        assignment = self.consumer.assignment()
+        queues: Set[TopicPartition] = set(TopicPartition(topic=t, partition=0) for t in queue_name)
+
+        new_topics = queues - assignment
+        if not new_topics:
+            # nothing new to subscribe on
+            return
+
+        topics = assignment | queues
+
+        self.consumer.assign(list(topics))
+        if not self.settings.consumer_group:
+            # seek to the end of each new topic subscribed so no historical messages will be fetched
+            await self.consumer.seek_to_end(*new_topics)
+
+    async def unsubscribe(self, queue_name: Iterable[str]):
+        queues: Set[TopicPartition] = set(TopicPartition(topic=t, partition=0) for t in queue_name)
+        topics = self.consumer.assignment() ^ queues
+
+        self.consumer.assign(list(topics))
+
+    async def commit(self, task: Task, timeout: float = None):
+        # no commits if no consumer group
+        if not self.settings.consumer_group:
+            return
+
+        await super().commit(task, timeout)
